<?php

namespace Drupal\creditreform\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Creditreform form.
 */
class GetHitListForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'creditreform_get_hit_list';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['what'] = [
      '#type'        => 'textfield',
      '#title'       => $this->t('What'),
      '#placeholder' => $this->t('Company Name'),
      '#required'    => TRUE,
    ];

    $form['where'] = [
      '#type'        => 'textfield',
      '#title'       => $this->t('Where'),
      '#placeholder' => $this->t('City'),
      '#required'    => TRUE,
    ];

    $form['country'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Country'),
      '#default_value' => 'CH',
      '#required'      => TRUE,
    ];

    $form['archive_type'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Archive Type'),
      '#default_value' => 'Business',
      '#required'      => TRUE,
    ];

    $form['match_level'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Match Level'),
      '#default_value' => 'Regular',
      '#required'      => TRUE,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type'  => 'submit',
      '#value' => $this->t('Send'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!in_array($form_state->getValue('archive_type'), ['Business'])) {
      $form_state->setErrorByName(
        'archive_type',
        $this->t('Archive Type must be "Business".')
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(
    array &$form,
    FormStateInterface $form_state
  ) {

    // Get Druapl Service CreditreformApi.
    $creditreform_api = \Drupal::service('creditreform.api');
    $result = $creditreform_api->getHitList(
      $form_state->getValue('what'),
      $form_state->getValue('where'),
      $form_state->getValue('country'),
      $form_state->getValue('archive_type'),
      $form_state->getValue('match_level')
    );

    $this->messenger()->addStatus(json_encode($result));
  }

}
